GSM now receives tones during bridge
[lcr.git] / gsm.h
diff --git a/gsm.h b/gsm.h
index 254797e..671aab6 100644 (file)
--- a/gsm.h
+++ b/gsm.h
@@ -15,7 +15,7 @@ enum {
 };
 
 struct lcr_gsm {
-       struct interface *interface;    /* interface this instance is associated to */
+       char interface_name[64]; /* name of interface this instance is associated to */
        struct lcr_gsm  *gsm_ms_next;   /* list of MS instances, in case of MS */
        char            name[16];       /* name of MS instance, in case of MS */
        int             type;           /* LCR_GSM_TYPE_*/
@@ -35,6 +35,7 @@ class Pgsm : public Port
        ~Pgsm();
 
        char p_g_interface_name[64];
+       signed short p_g_samples[160]; /* last received audi packet */
        int p_g_tones; /* set, if tones are to be generated */
        int p_g_earlyb; /* set, if patterns are available */
        struct lcr_gsm *p_g_lcr_gsm; /* pointer to network/ms instance */
@@ -59,6 +60,7 @@ class Pgsm : public Port
 
        void frame_send(void *_frame);
        void frame_receive(void *_frame);
+       int audio_send(unsigned char *data, int len);
        int bridge_rx(unsigned char *data, int len);
 
        int hunt_bchannel(void);